import numpy as np
import matplotlib.pyplot as plt

# plot gradient descent trajectory

def plot_gd_trajs(fnames, i_column, n_column, optimal_seq, x_label=None):
    n_files = len(fnames)
    for i_file in range(n_files):
        data = np.loadtxt(fnames[i_file])[:, :8]
        n_steps = np.shape(data)[0]
        n_beads = np.shape(data)[1]
        if i_file == 0:
            data_all = np.zeros((n_steps, n_beads, n_files))
        data_all[:, :, i_file] = data
    for i_bead in range(n_beads):
        plt.subplot(n_beads, n_column, i_column + i_bead * n_column)
        for i_file in range(n_files):
            plt.plot(np.arange(n_steps), data_all[:, i_bead, i_file])
        plt.plot([0, n_steps], [optimal_seq[i_bead], optimal_seq[i_bead]], 'k--')
        plt.ylim([-1.5, 1.5])
        plt.xlim([0, 100])
        if i_column > 1:
            plt.yticks([], [])
        if i_bead != n_beads - 1:
            plt.xticks([], [])
        if i_bead == n_beads - 1:
            if x_label is None:
                plt.xlabel('Steps')
            else:
                plt.xlabel(x_label)
        if i_column == 1:
            if i_bead == n_beads - 1:
                plt.ylabel(r'$\xi$')

if __name__ == '__main__':

    plot_gd_trajs(['gd_allhydrophilic/grad_descent_traj_start0.9.txt',
                   'gd_allhydrophilic/grad_descent_traj_start0.5.txt',
                   'gd_allhydrophilic/grad_descent_traj_rand1.txt',
                   'gd_allhydrophilic/grad_descent_traj_rand2.txt',
                   'gd_allhydrophilic/grad_descent_traj_rand3.txt',
                   'gd_allhydrophilic/grad_descent_traj_rand4.txt'],
                  1, 4, [-1]*15, x_label='Hydrophilic')
    plot_gd_trajs(['gd_hydrophobicends/grad_descent_traj_start0.9.txt',
                   'gd_hydrophobicends/grad_descent_traj_start0.5.txt',
                   'gd_hydrophobicends/grad_descent_traj_rand1.txt',
                   'gd_hydrophobicends/grad_descent_traj_rand2.txt',
                   'gd_hydrophobicends/grad_descent_traj_rand3.txt',
                   'gd_hydrophobicends/grad_descent_traj_rand4.txt'],
                  2, 4, [1, 1, 1, 1, 1, -1, -1, -1, -1, -1, 1, 1, 1, 1, 1], 
                  x_label='Hydrophobic ends')
    plot_gd_trajs(['gd_alternating/grad_descent_traj_start0.9.txt',
                   'gd_alternating/grad_descent_traj_start0.5.txt',
                   'gd_alternating/grad_descent_traj_rand1.txt',
                   'gd_alternating/grad_descent_traj_rand2.txt',
                   'gd_alternating/grad_descent_traj_rand3.txt',
                   'gd_alternating/grad_descent_traj_rand4.txt'],
                  3, 4, [1, -1, 1, -1, 1, -1, 1, -1, 1, -1, 1, -1, 1, -1, 1], 
                  x_label='Alternating')
    plot_gd_trajs(['gd_halfhydrophobic/grad_descent_traj_start0.9.txt',
                   'gd_halfhydrophobic/grad_descent_traj_start0.5.txt',
                   'gd_halfhydrophobic/grad_descent_traj_rand1.txt',
                   'gd_halfhydrophobic/grad_descent_traj_rand2.txt',
                   'gd_halfhydrophobic/grad_descent_traj_rand3.txt',
                   'gd_halfhydrophobic/grad_descent_traj_rand4.txt'],
                  4, 4, [1, 1, 1, 1, 1, 1, 1, 1, -1, -1, -1, -1, -1, -1, -1], 
                  x_label='Diblock copolymer')
    plt.subplots_adjust(wspace=0, hspace=0)
    plt.savefig('gd_traj.png', dpi=200, bbox_inches='tight')
    
