import numpy as np
import matplotlib.pyplot as plt

# basic plotting of the end-to-end distance distribution

# find the mean of the end-to-end distance distribution
def _mean(r, pr):
    return np.sum(pr * r) / np.sum(pr)

# plot the end-to-end distance trajectory
def plot_ree_traj(fname, ree_save_freq):
    ree = np.loadtxt(fname)
    steps = ree_save_freq * np.arange(len(ree))
    plt.plot(steps, ree)
    plt.show()

# plot the end-to-end distance distribution
def plot_pr(fname, bin_edges=np.arange(0, 10.5, 0.5), plot_mean=False, print_std=False, plot_label='', plot_color=None, plot_format='o-'):
    ree = np.loadtxt(fname)
    hist, bin_edges = np.histogram(ree, bins=bin_edges, density=True)
    bin_centers = (bin_edges[:-1]+bin_edges[1:])/2.
    if plot_color is not None:
        p = plt.plot(bin_centers, hist, plot_format, label=r''+plot_label, color=plot_color)
    else:
        p = plt.plot(bin_centers, hist, plot_format, label=r''+plot_label)
    if plot_mean:
        ree_avg = _mean(bin_centers, hist)
        plt.plot([ree_avg, ree_avg], [0, 1], '--', color=p[0].get_color())
    if print_std:
        ree_mean = np.mean(ree)
        var = np.sum(ree * ree) / len(ree) - ree_mean * ree_mean
        print('std', fname, np.sqrt(var))
    return p

if __name__ == '__main__':

    plot_pr('ree_seq111111111111111_T1.0.txt', plot_mean=True, print_std=True, plot_label='$T_{15}$')
    plot_pr('ree_seqn1n1n1n1n1n1n1n1n1n1n1n1n1n1n1_T1.0.txt', plot_mean=True, print_std=True, plot_label='$H_{15}$')
    plot_pr('ree_seq11111n1n1n1n1n111111_T1.0.txt', plot_mean=True, print_std=True, plot_label='$T_5H_5T_5$')
    plot_pr('ree_seq11111111n1n1n1n1n1n1n1_T1.0.txt', plot_mean=True, print_std=True, plot_label='$T_8H_7$')
    plt.legend(edgecolor='None')
    plt.xlabel(r'$R_{ee}$')
    plt.ylabel(r'$P(R_{ee})$')
    plt.ylim([0, 0.5])
    plt.savefig('example_ree.png', dpi=200, bbox_inches='tight')
    
